# -*- coding: utf-8 -*-
# Generated by Django 1.10.1 on 2016-10-20 13:47
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django_resized.forms
import ovp_uploads.models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('ovp_uploads', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='UploadedImage',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('image', models.ImageField(upload_to=ovp_uploads.models.ImageName(), verbose_name='Image 350x260')),
                ('image_small', django_resized.forms.ResizedImageField(blank=True, default=None, null=True, upload_to=ovp_uploads.models.ImageName('-small'))),
                ('image_medium', django_resized.forms.ResizedImageField(blank=True, default=None, null=True, upload_to=ovp_uploads.models.ImageName('-medium'))),
                ('image_large', django_resized.forms.ResizedImageField(blank=True, default=None, null=True, upload_to=ovp_uploads.models.ImageName('-large'))),
                ('created_date', models.DateTimeField(auto_now_add=True)),
                ('modified_date', models.DateTimeField(auto_now=True)),
                ('user', models.ForeignKey(blank=True, default=None, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name': 'uploaded image',
                'verbose_name_plural': 'uploaded images',
            },
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.1 on 2016-10-24 19:59
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ovp_uploads', '0002_uploadedimage'),
    ]

    operations = [
        migrations.AddField(
            model_name='uploadedimage',
            name='uuid',
            field=models.CharField(blank=True, default=None, max_length=36, verbose_name='UUID'),
        ),
    ]



from ovp_uploads.models import UploadedImage

from rest_framework import serializers

class UploadedImageSerializer(serializers.ModelSerializer):
  image_url = serializers.CharField(source="get_image_url", required=False, read_only=True)
  image_small_url = serializers.CharField(source="get_image_small_url", required=False, read_only=True)
  image_medium_url = serializers.CharField(source="get_image_medium_url", required=False, read_only=True)
  image_large_url = serializers.CharField(source="get_image_large_url", required=False, read_only=True)

  class Meta:
    model = UploadedImage
    fields = ('id', 'user', 'image', 'image_url', 'image_small_url', 'image_medium_url', 'image_large_url')
    read_only_fields = ('image_small', 'image_medium', 'image_large')



# -*- coding: utf-8 -*-
from setuptools import setup, find_packages

setup(
    name='ovp-uploads',
    version='0.1.4',
    author=u'Atados',
    author_email='arroyo@atados.com.br',
    packages=find_packages(),
    url='https://github.com/OpenVolunteeringPlatform/django-ovp-uploads',
    download_url = 'https://github.com/OpenVolunteeringPlatform/django-ovp-core/tarball/0.1.4',
    license='AGPL',
    description='This module has core upload functionality.',
    long_description=open('README.rst', encoding='utf-8').read(),
    zip_safe=False,
    install_requires = [
      'Django>=1.10.1,<1.11.0',
      'djangorestframework>=3.4.7,<3.5.0',
      'codecov>=2.0.5,<2.1.0',
      'coverage>=4.2,<4.3.0',
      'django-resized>=0.3.5,<0.4.0',
      'Pillow>=3.4.2,<3.5',
      'ovp-users>=1.0.1,<2.0',
      'django-storages>=1.5.1,<1.6',
    ]
)
